/**
 * @packageDocumentation
 *
 * A Datastore implementation for browsers that stores data in [IndexedDB](https://developer.mozilla.org/en-US/docs/Web/API/IndexedDB_API).
 *
 * @example
 *
 * ```js
 * import { IDBDatastore } from 'datastore-idb'
 *
 * const store = new IDBDatastore('path/to/store')
 * ```
 */
import { BaseDatastore } from 'datastore-core';
import { Key } from 'interface-datastore';
import type { Batch, KeyQuery, Pair, Query } from 'interface-datastore';
import type { AbortOptions } from 'interface-store';
export interface IDBDatastoreInit {
    /**
     * A prefix to use for all database keys (default: '')
     */
    prefix?: string;
    /**
     * The database version (default: 1)
     */
    version?: number;
}
export declare class IDBDatastore extends BaseDatastore {
    #private;
    private readonly location;
    private readonly version;
    private db?;
    constructor(location: string, init?: IDBDatastoreInit);
    open(): Promise<void>;
    close(): Promise<void>;
    put(key: Key, val: Uint8Array, options?: AbortOptions): Promise<Key>;
    get(key: Key, options?: AbortOptions): Promise<Uint8Array>;
    has(key: Key, options?: AbortOptions): Promise<boolean>;
    delete(key: Key, options?: AbortOptions): Promise<void>;
    batch(): Batch;
    query(q: Query, options?: AbortOptions): AsyncIterable<Pair>;
    queryKeys(q: KeyQuery, options?: AbortOptions): AsyncIterable<Key>;
    destroy(): Promise<void>;
}
//# sourceMappingURL=index.d.ts.map